| CWD | R Documentation |
Carbon flux on six pieces of wood.
CWD
A data frame with 13 observations on 8 variables.
sample2carbon flux measurement for 2nd piece of wood.
sample3carbon flux measurement for 3rd piece of wood.
sample4carbon flux measurement for 4th piece of wood.
sample6carbon flux measurement for 6th piece of wood.
sample7carbon flux measurement for 7th piece of wood.
sample8carbon flux measurement for 8th piece of wood.
trendmeasurement day (in days from beginning).
timedate of measurement.
Coarse woody debris (CWD, dead wood greater than 10 cm in diameter) is a large stock of carbon in tropical forests, yet the flux of carbon out of this pool, via respiration, is poorly resolved \bibcitepcoin::chambers_2001. The heterotrophic process involved in CWD respiration should respond to reductions in moisture availability, which occurs during dry season \bibcitepcoin::chambers_2001.
CWD respiration measurements were taken in a tropical forest in west French Guiana, which experiences extreme contrasts in wet and dry season \bibcitepcoin::bonal_2008. An infrared gas analyzer and a clear chamber sealed to the wood surface were used to measure the flux of carbon out of the wood \bibcitepcoin::stahl_2011. Measurements were repeated 13 times, from July to November 2011, on six pieces of wood during the transition into and out of the dry season. The aim is to assess if there were shifts in the CWD respiration of any of the pieces in response to the transition into (early August) and out of (late October) the dry season.
\bibcitetcoin::Zeileis_Hothorn_2013 investigated the six-variate series of CO_2
reflux, aiming to find out whether the reflux had changed over the sampling
period in at least one of the six wood pieces.
The coarse woody debris respiration data were kindly provided by Lucy Rowland (School of GeoSciences, University of Edinburgh).
*
## Zeileis and Hothorn (2013, pp. 942-944)
## Approximative (Monte Carlo) maximally selected statistics
CWD[1:6] <- 100 * CWD[1:6] # scaling (to avoid harmless warning)
mt <- maxstat_test(sample2 + sample3 + sample4 +
sample6 + sample7 + sample8 ~ trend, data = CWD,
distribution = approximate(nresample = 100000))
## Absolute maximum of standardized statistics (t = 3.08)
statistic(mt)
## 5% critical value (t_0.05 = 2.86)
(c <- qperm(mt, 0.95))
## Only 'sample8' exceeds the 5% critical value
sts <- statistic(mt, type = "standardized")
idx <- which(sts > c, arr.ind = TRUE)
sts[unique(idx[, 1]), unique(idx[, 2]), drop = FALSE]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.