The coin package provides an implementation of a general framework for
conditional inference procedures commonly known as permutation tests.
The framework was developed by coin::strasserweber1999 and is based on a
multivariate linear statistic and its conditional expectation, covariance and
limiting distribution. These results are utilized to construct tests of
independence between two sets of variables.
The package does not only provide a flexible implementation of the abstract
framework, but also provides a large set of convenience functions implementing
well-known as well as lesser-known classical and non-classical test procedures
within the framework. Many of the tests presented in prominent text books,
such as coin::hollanderwolfe1999 or
coin::agresti2002, are immediately
available or can be implemented without much effort. Examples include linear
rank statistics for the two- and \(K\)-sample location and scale problem
against ordered and unordered alternatives including post-hoc tests for
arbitrary contrasts, tests of independence for contingency tables, two- and
\(K\)-sample tests for censored data, tests of independence between two
continuous variables as well as tests of marginal homogeneity and symmetry.
Approximations of the exact null distribution via the limiting distribution or
conditional Monte Carlo resampling are available for every test procedure,
while the exact null distribution is currently available for univariate
two-sample problems only.
The salient parts of the Strasser-Weber framework are elucidated by
coin::hothorn:2006:amstat and a thorough description of the software implementation
is given by coin::hothorn+hornik+vandewiel:2008.