| rotarod | R Documentation |
The endurance time of 24 rats in two groups on a rotating cylinder.
rotarod
A data frame with 24 observations on 2 variables.
timeendurance time (seconds).
groupa factor with levels "control" and "treatment".
The rats were randomly assigned to receive a fixed oral dose of a centrally
acting muscle relaxant ("treatment") or a saline solvent
("control"). The animals were placed on a rotating cylinder and the
endurance time of each rat, i.e., the length of time each rat remained on the
cylinder, was measured up to a maximum of 300 seconds.
This dataset is the basis of a comparison of 11 different software implementations of the Wilcoxon-Mann-Whitney test presented in \bibcitetcoin::bergmann:2000.
The empirical variance in the control group is 0 and the group medians are
identical. The exact conditional p-values are 0.0373 (two-sided) and
0.0186 (one-sided). The asymptotic two-sided p-value (corrected for
ties) is 0.0147.
*
## One-sided exact Wilcoxon-Mann-Whitney test (p = 0.0186)
wilcox_test(time ~ group, data = rotarod, distribution = "exact",
alternative = "greater")
## Two-sided exact Wilcoxon-Mann-Whitney test (p = 0.0373)
wilcox_test(time ~ group, data = rotarod, distribution = "exact")
## Two-sided asymptotic Wilcoxon-Mann-Whitney test (p = 0.0147)
wilcox_test(time ~ group, data = rotarod)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.