vision: Unaided Distance Vision

visionR Documentation

Unaided Distance Vision

Description

Assessment of unaided distance vision of women in Britain.

Usage

vision

Format

A contingency table with 7477 observations on 2 variables.

Right.Eye

a factor with levels "Highest Grade", "Second Grade", "Third Grade" and "Lowest Grade".

Left.Eye

a factor with levels "Highest Grade", "Second Grade", "Third Grade" and "Lowest Grade".

Details

Paired ordered categorical data from case-records of eye-testing of 7477 women aged 30–39 years employed by Royal Ordnance Factories in Britain during 1943–46, as given by \bibcitetcoin::stuart_1955.

This data set was used by \bibcitetcoin::stuart_1955 to illustrate a test of marginal homogeneity. \bibcitetcoin::winell_2018 also used the data, demonstrating a score-independent test for ordered categorical data.

References

\bibshow

*

Examples

## Asymptotic Stuart test (Q = 11.96)
diag(vision) <- 0 # speed-up
mh_test(vision)

## Asymptotic score-independent test
## Winell and Lindbaeck (2018)
(st <- symmetry_test(vision,
                     ytrafo = function(data)
                         trafo(data, factor_trafo = function(y)
                             zheng_trafo(as.ordered(y)))))
ss <- statistic(st, type = "standardized")
idx <- which(abs(ss) == max(abs(ss)), arr.ind = TRUE)
ss[idx[1], idx[2], drop = FALSE]

coin documentation built on June 30, 2026, 9:06 a.m.