Specification of the asymptotic, approximative (Monte Carlo) and exact reference distribution.
asymptotic(maxpts = 25000, abseps = 0.001, releps = 0)
approximate(nresample = 10000L, parallel = c("no", "multicore", "snow"),
ncpus = 1L, cl = NULL, B)
exact(algorithm = c("auto", "shift", "split-up"), fact = NULL)
an integer, the maximum number of function values. Defaults to
25000.
a numeric, the absolute error tolerance. Defaults to 0.001.
a numeric, the relative error tolerance. Defaults to 0.
a positive integer, the number of Monte Carlo replicates used for the
computation of the approximative reference distribution. Defaults to
10000L.
a character, the type of parallel operation: either "no" (default),
"multicore" or "snow".
an integer, the number of processes to be used in parallel operation.
Defaults to 1L.
an object inheriting from class "cluster", specifying an optional
parallel or snow cluster if parallel = "snow". Defaults
to NULL.
deprecated, use nresample instead.
a character, the algorithm used for the computation of the exact reference
distribution: either "auto" (default), "shift" or
"split-up".
an integer to multiply the response values with. Defaults to NULL.
asymptotic(), approximate() and exact() can be supplied
to the distribution argument of, e.g.,
independence_test() to provide control of the specification of
the asymptotic, approximative (Monte Carlo) and exact reference distribution,
respectively.
The asymptotic reference distribution is computed using a randomised
quasi-Monte Carlo method coin::Genz_Bretz_2009 and is applicable to arbitrary
covariance structures with dimensions up to 1000. See
GenzBretz() in package mvtnorm for
details on maxpts, abseps and releps.
The approximative (Monte Carlo) reference distribution is obtained by a
conditional Monte Carlo procedure, i.e., by computing the test statistic for
nresample random samples from all admissible permutations of the
response \(\bf{Y}\) within each block
coin::hothorn+hornik+vandewiel:2008. By
default, the distribution is computed using serial operation
(parallel = "no"). The use of parallel operation is specified by
setting parallel to either "multicore" (not available for MS
Windows) or "snow". In the latter case, if cl = NULL (default)
a cluster with ncpus processes is created on the local machine unless a
default cluster has been registered (see
setDefaultCluster() in package
parallel) in which case that gets used instead. Alternatively, the use
of an optional parallel or snow cluster can be specified by
cl. See ‘Examples’ and package parallel for details on
parallel operation.
The exact reference distribution, currently available for univariate
two-sample problems only, is computed using either the shift algorithm
coin::streitberg_1984,coin::axact-dist:1986,coin::exakte-ver:1987
or the split-up
algorithm coin::vdwiel2001. The shift algorithm handles blocks pertaining
to, e.g., pre- and post-stratification, but can only be used with positive
integer-valued scores \(h(\bf{Y})\). The split-up algorithm can be
used with non-integer scores, but does not handle blocks. By default, an
automatic choice is made (algorithm = "auto") but the shift and
split-up algorithms can be selected by setting algorithm to
"shift" or "split-up", respectively.
*