Objects from the Class
Class "VarCovar" is a virtual class defined as the class union
of "CovarianceMatrix" and "Variance", so objects cannot be
created from it directly.
Objects can be created by calls of the form new("CovarianceMatrix", covariance, \dots)
and new("Variance", variance, \dots).
where covariance is a covariance matrix and variance is numeric
vector containing the diagonal elements of the covariance matrix.Extends
For objects of classes "CovarianceMatrix" or "Variance":
Class "VarCovar", directly.Known Subclasses
For objects of class "VarCovar":
Class "CovarianceMatrix", directly.
Class "Variance", directly.