asat: Toxicological Study on Female Wistar Rats

asatR Documentation

Toxicological Study on Female Wistar Rats

Description

Measurements of the liver enzyme aspartate aminotransferase (ASAT) for a new compound and a control group of 34 female Wistar rats.

Usage

asat

Format

A data frame with 34 observations on 2 variables.

asat

ASAT values.

group

a factor with levels "Compound" and "Control".

Details

The aim of this toxicological study is the proof of safety for the new compound. The data were originally given in \bibcitetcoin::Hothorn1992 and later reproduced by \bibcitetcoin::Hauschke_1999, see also \bibcitetcoin::pflueger_2002.

References

\bibshow

*

Examples

## Proof-of-safety based on ratio of medians (Pflueger and Hothorn, 2002)
## One-sided exact Wilcoxon-Mann-Whitney test
wt <- wilcox_test(I(log(asat)) ~ group, data = asat,
                  distribution = "exact", alternative = "less",
                  conf.int = TRUE)

## One-sided confidence set
## Note: Safety cannot be concluded since the effect of the compound
##       exceeds 20 % of the control median
exp(confint(wt)$conf.int)

coin documentation built on June 30, 2026, 9:06 a.m.