| asat | R Documentation |
Measurements of the liver enzyme aspartate aminotransferase (ASAT) for a new compound and a control group of 34 female Wistar rats.
asat
A data frame with 34 observations on 2 variables.
asatASAT values.
groupa factor with levels "Compound" and "Control".
The aim of this toxicological study is the proof of safety for the new compound. The data were originally given in \bibcitetcoin::Hothorn1992 and later reproduced by \bibcitetcoin::Hauschke_1999, see also \bibcitetcoin::pflueger_2002.
*
## Proof-of-safety based on ratio of medians (Pflueger and Hothorn, 2002)
## One-sided exact Wilcoxon-Mann-Whitney test
wt <- wilcox_test(I(log(asat)) ~ group, data = asat,
distribution = "exact", alternative = "less",
conf.int = TRUE)
## One-sided confidence set
## Note: Safety cannot be concluded since the effect of the compound
## exceeds 20 % of the control median
exp(confint(wt)$conf.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.